pitchtools.calculate_melodic_counterpoint_interval
==================================================

.. autofunction:: abjad.tools.pitchtools.calculate_melodic_counterpoint_interval.calculate_melodic_counterpoint_interval
   :noindex:
